# Auto-generated by DjangoCFG - see CLAUDE.md

from .client import EmailGatewayEmailAPI
from .models import (
    EmailAccountCreateRequest,
    EmailAccountList,
    EmailMessageList,
    EmailSendRequest,
    EmailSendResponse,
    TestConnectionResponse,
)
from .sync_client import SyncEmailGatewayEmailAPI

__all__ = [
    "EmailGatewayEmailAPI",
    "SyncEmailGatewayEmailAPI",
    "EmailAccountCreateRequest",
    "EmailAccountList",
    "EmailMessageList",
    "EmailSendRequest",
    "EmailSendResponse",
    "TestConnectionResponse",
]